==> react-native-scanbot-sdk-6.1.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/barcode_scanner_view/ScanbotBarcodeScannerView.kt <==
package io.scanbot.sdk.reactnative.components.barcode_scanner_view

import android.Manifest
import android.app.Activity
import android.content.Context
import android.content.pm.PackageManager
import android.util.AttributeSet
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.core.app.ActivityCompat
import com.facebook.react.bridge.LifecycleEventListener
import com.facebook.react.bridge.ReactContext
import com.facebook.react.uimanager.UIManagerHelper
import io.scanbot.sdk.ScanbotSDK
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.CameraConfiguration
import io.scanbot.sdk.reactnative.models.FinderViewConfiguration
import io.scanbot.sdk.reactnative.models.PolygonStyleConfig
import io.scanbot.sdk.reactnative.models.SelectedBarcodes
import io.scanbot.sdk.reactnative.models.TextStyleConfig
import io.scanbot.sdk.barcode.entity.BarcodeItem
import io.scanbot.sdk.barcode.ui.BarcodePolygonsView
import io.scanbot.sdk.barcode.ui.BarcodeScannerView
import io.scanbot.sdk.barcode.ui.IBarcodeScannerFinderViewController
import io.scanbot.sdk.barcode.ui.IBarcodeScannerSelectionOverlayController
import io.scanbot.sdk.barcode.ui.IBarcodeScannerViewCallback
import io.scanbot.sdk.camera.CaptureInfo
import io.scanbot.sdk.camera.FrameHandlerResult
import io.scanbot.sdk.ui.camera.CameraUiSettings

class ScanbotBarcodeScannerView(
    context: Context,
    attrs: AttributeSet?,
    defStyleAttr: Int,
    defStyleRes: Int
) : FrameLayout(context, attrs, defStyleAttr, defStyleRes) {

    constructor(context: Context) : this(context, null)
    constructor(context: Context, attrs: AttributeSet?) : this(context, attrs, 0)
    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : this(
        context,
        attrs,
        defStyleAttr,
        0
    )

    companion object {
        private const val CAMERA_PERMISSION_REQUEST_CODE = 3331
        private const val INITIAL_FLASH_STATE = false
        private const val BARCODE_DETECTION_INTERVAL = 0L
    }

    val barcodeDetector = ScanbotSDK(context).createBarcodeDetector()

    lateinit var barcodeScanner: BarcodeScannerView
        private set

    var flashState: Boolean = INITIAL_FLASH_STATE
    var polygonStyle = PolygonStyleConfig()
    var textStyle = TextStyleConfig()
    var selectedBarcodes: List<SelectedBarcodes> = emptyList()

    private var cameraPermissionRequested = false

    private var lifecycleEventListener: LifecycleEventListener = object : LifecycleEventListener {
        override fun onHostResume() {
            requestCameraPermissionIfNotGranted()
            barcodeScanner.viewController.onResume()
        }

        override fun onHostPause() {
            barcodeScanner.viewController.onPause()
        }

        override fun onHostDestroy() {

        }
    }

    init {
        initBarcodeScannerView()

        layoutParams = ViewGroup.LayoutParams(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.MATCH_PARENT,
        )
        addView(barcodeScanner)
    }

    override fun onAttachedToWindow() {
        super.onAttachedToWindow()
        this.barcodeScanner.viewController.onResume()
    }

    override fun onDetachedFromWindow() {
        this.barcodeScanner.viewController.onPause()
        super.onDetachedFromWindow()
    }

    fun removeAttachedListeners() {
        (context as ReactContext).removeLifecycleEventListener(lifecycleEventListener)
    }


    private fun initBarcodeScannerView() {
        barcodeScanner = BarcodeScannerView(context).apply {
            initCamera(CameraUiSettings(true))

            initDetectionBehavior(barcodeDetector, {
                (it as? FrameHandlerResult.Success)?.value?.let { result ->
                    sendEvent(BarcodeScannerResultEvent(result))
                }

                false
            }, object : IBarcodeScannerViewCallback {
                override fun onCameraOpen() {
                    viewController.useFlash(flashState)
                }

                override fun onPictureTaken(image: ByteArray, captureInfo: CaptureInfo) {
                }

                override fun onSelectionOverlayBarcodeClicked(barcodeItem: BarcodeItem) {
                    sendEvent(BarcodeSelectionResultEvent(barcodeItem))
                }
            })

            viewController.barcodeDetectionInterval = BARCODE_DETECTION_INTERVAL

            configureFinderViewControllerWithDefaults(finderViewController)

            cameraConfiguration.setPhysicalZoomRange(CameraConfiguration.DEFAULT_ZOOM_RANGE)

            configureSelectionOverlayControllerWithDefaults(selectionOverlayController)

            (context as ReactContext).addLifecycleEventListener(lifecycleEventListener)
        }
    }

    private fun configureFinderViewControllerWithDefaults(finderViewController: IBarcodeScannerFinderViewController) {
        finderViewController.setStrokeColor(FinderViewConfiguration.DEFAULT_STROKE_COLOR)
        finderViewController.setOverlayColor(FinderViewConfiguration.DEFAULT_OVERLAY_COLOR)
        finderViewController.setFinderEnabled(FinderViewConfiguration.DEFAULT_FINDER_ENABLED)
        finderViewController.setStrokeWidth(
            FinderViewConfiguration.DEFAULT_STROKE_WIDTH.toPx(
                resources
            )
        )
        finderViewController.setFinderMinPadding(
            FinderViewConfiguration.DEFAULT_FINDER_MIN_PADDING.toPx(
                resources
            )
        )
        finderViewController.setFinderInset(
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.left.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.top.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.right.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.bottom.toPx(resources)
        )
        finderViewController.setRequiredAspectRatios(FinderViewConfiguration.DEFAULT_ASPECT_RATIO)
    }

    private fun configureSelectionOverlayControllerWithDefaults(selectionOverlayController: IBarcodeScannerSelectionOverlayController) {
        selectionOverlayController.setBarcodeAppearanceDelegate(object :
            BarcodePolygonsView.BarcodeAppearanceDelegate {
            override fun getPolygonStyle(
                defaultStyle: BarcodePolygonsView.BarcodePolygonStyle, barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodePolygonStyle {
                return defaultStyle.copy(
                    fillColor = PolygonStyleConfig.DEFAULT_FILL_COLOR,
                    fillHighlightedColor = PolygonStyleConfig.DEFAULT_FILL_HIGHLIGHTED_COLOR,
                    strokeColor = PolygonStyleConfig.DEFAULT_STROKE_COLOR,
                    strokeHighlightedColor = PolygonStyleConfig.DEFAULT_STROKE_HIGHLIGHTED_COLOR
                )
            }

            override fun getTextViewStyle(
                defaultStyle: BarcodePolygonsView.BarcodeTextViewStyle, barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodeTextViewStyle {
                return defaultStyle.copy(
                    textColor = TextStyleConfig.DEFAULT_TEXT_COLOR,
                    textHighlightedColor = TextStyleConfig.DEFAULT_TEXT_HIGHLIGHTED_COLOR,
                    textContainerColor = TextStyleConfig.DEFAULT_TEXT_CONTAINER_COLOR,
                    textContainerHighlightedColor = TextStyleConfig.DEFAULT_TEXT_CONTAINER_HIGHLIGHTED_COLOR,
                    textFormat = TextStyleConfig.DEFAULT_TEXT_FORMAT
                )
            }
        })

        selectionOverlayController.setBarcodeHighlightedDelegate(object :
            BarcodePolygonsView.BarcodeHighlightDelegate {
            override fun shouldHighlight(barcodeItem: BarcodeItem): Boolean {
                return selectedBarcodes.any {
                    it.type == barcodeItem.barcodeFormat && it.textWithExtension == barcodeItem.textWithExtension
                }
            }
        })
    }

    override fun requestLayout() {
        super.requestLayout()
        post {
            layoutView()
        }
    }

    private fun View.layoutView() {
        measure(
            MeasureSpec.makeMeasureSpec(measuredWidth, MeasureSpec.EXACTLY),
            MeasureSpec.makeMeasureSpec(measuredHeight, MeasureSpec.EXACTLY)
        )
        layout(left, top, right, bottom)
    }

    private fun sendEvent(event: BaseEvent) {
        val surfaceId = UIManagerHelper.getSurfaceId(this)

        UIManagerHelper.getEventDispatcherForReactTag((context as ReactContext), id)
            ?.dispatchEvent(ComponentEvent(event, surfaceId, id))
    }

    private fun requestCameraPermissionIfNotGranted() {
        val activity: Activity = (context as ReactContext).currentActivity ?: return

        if (!cameraPermissionRequested &&
            ActivityCompat.checkSelfPermission(
                activity,
                Manifest.permission.CAMERA
            ) != PackageManager.PERMISSION_GRANTED
        ) {
            // shouldShowRequestPermissionRationale can be changed from another place in the app,
            // that's why we are using custom flag
            cameraPermissionRequested = true

            ActivityCompat.requestPermissions(
                activity,
                arrayOf(Manifest.permission.CAMERA),
                CAMERA_PERMISSION_REQUEST_CODE
            )
        }
    }

    fun setOverlayAppearance() {
        barcodeScanner.selectionOverlayController.setBarcodeAppearanceDelegate(object :
            BarcodePolygonsView.BarcodeAppearanceDelegate {
            override fun getPolygonStyle(
                defaultStyle: BarcodePolygonsView.BarcodePolygonStyle,
                barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodePolygonStyle {
                return defaultStyle.copy(
                    fillColor = polygonStyle.fillColor!!,
                    fillHighlightedColor = polygonStyle.fillHighlightedColor!!,
                    strokeColor = polygonStyle.strokeColor!!,
                    strokeHighlightedColor = polygonStyle.strokeHighlightedColor!!,
                )
            }

            override fun getTextViewStyle(
                defaultStyle: BarcodePolygonsView.BarcodeTextViewStyle,
                barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodeTextViewStyle {
                return defaultStyle.copy(
                    textColor = textStyle.textColor!!,
                    textHighlightedColor = textStyle.textHighlightedColor!!,
                    textContainerColor = textStyle.textContainerColor!!,
                    textContainerHighlightedColor = textStyle.textContainerHighlightedColor!!,
                    textFormat = textStyle.textFormat!!
                )
            }
        })
    }
}

==> react-native-scanbot-sdk-6.2.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/barcode_scanner_view/ScanbotBarcodeScannerView.kt <==
package io.scanbot.sdk.reactnative.components.barcode_scanner_view

import android.Manifest
import android.app.Activity
import android.content.Context
import android.content.pm.PackageManager
import android.content.res.ColorStateList
import android.graphics.Color
import android.util.AttributeSet
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.FrameLayout
import androidx.core.app.ActivityCompat
import com.facebook.react.bridge.LifecycleEventListener
import com.facebook.react.bridge.ReactContext
import com.facebook.react.uimanager.UIManagerHelper
import io.scanbot.sdk.ScanbotSDK
import io.scanbot.sdk.barcode.entity.BarcodeItem
import io.scanbot.sdk.barcode.entity.BarcodeScanningResult
import io.scanbot.sdk.barcode.ui.BarcodePolygonsView
import io.scanbot.sdk.barcode.ui.BarcodeScannerView
import io.scanbot.sdk.barcode.ui.IBarcodeScannerFinderViewController
import io.scanbot.sdk.barcode.ui.IBarcodeScannerSelectionOverlayController
import io.scanbot.sdk.barcode.ui.IBarcodeScannerViewCallback
import io.scanbot.sdk.camera.CaptureInfo
import io.scanbot.sdk.camera.FrameHandlerResult
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.BarcodeItemOverlayViewConfig
import io.scanbot.sdk.reactnative.models.BaseEvent
import io.scanbot.sdk.reactnative.models.CameraConfiguration
import io.scanbot.sdk.reactnative.models.ComponentEvent
import io.scanbot.sdk.reactnative.models.FinderViewConfiguration
import io.scanbot.sdk.reactnative.models.PolygonStyleConfig
import io.scanbot.sdk.reactnative.models.TextStyleConfig
import io.scanbot.sdk.ui.camera.CameraUiSettings
import io.scanbot.sdk_wrapper.barcode.extensions.uuid

class ScanbotBarcodeScannerView(
    context: Context,
    attrs: AttributeSet?,
    defStyleAttr: Int,
    defStyleRes: Int
) : FrameLayout(context, attrs, defStyleAttr, defStyleRes) {

    constructor(context: Context) : this(context, null)
    constructor(context: Context, attrs: AttributeSet?) : this(context, attrs, 0)
    constructor(context: Context, attrs: AttributeSet?, defStyleAttr: Int) : this(
        context,
        attrs,
        defStyleAttr,
        0
    )

    companion object {
        private const val CAMERA_PERMISSION_REQUEST_CODE = 3331
        private const val INITIAL_FLASH_STATE = false
        private const val BARCODE_DETECTION_INTERVAL = 0L
    }

    val barcodeDetector = ScanbotSDK(context).createBarcodeDetector()

    lateinit var barcodeScanner: BarcodeScannerView
        private set

    var flashState: Boolean = INITIAL_FLASH_STATE
    var polygonStyle = PolygonStyleConfig()
    var textStyle = TextStyleConfig()

    private var cameraPermissionRequested = false

    private var barcodeItemOverlayViewBinders: MutableMap<String, BarcodeItemOverlayViewConfig>? =
        null

    private val barcodeItemOverlayViewBinder: BarcodePolygonsView.BarcodeItemViewBinder =
        object : BarcodePolygonsView.BarcodeItemViewBinder {
            override fun bindView(view: View, barcodeItem: BarcodeItem, shouldHighlight: Boolean) {
                (view as? Button)?.let { buttonView ->
                    barcodeItemOverlayViewBinders?.get(barcodeItem.uuid())
                        ?.let { overlayViewConfig ->
                            buttonView.text = overlayViewConfig.text

                            // buttonView doesn't use global overlay configuration by default
                            buttonView.setTextColor(
                                overlayViewConfig.textColorParsed ?: textStyle.textColor!!
                            )
                            buttonView.backgroundTintList = ColorStateList.valueOf(
                                overlayViewConfig.textContainerColorParsed
                                    ?: textStyle.textContainerColor!!
                            )
                        }
                }
            }
        }

    private var lifecycleEventListener: LifecycleEventListener = object : LifecycleEventListener {
        override fun onHostResume() {
            requestCameraPermissionIfNotGranted()
            barcodeScanner.viewController.onResume()
        }

        override fun onHostPause() {
            barcodeScanner.viewController.onPause()
        }

        override fun onHostDestroy() {

        }
    }

    init {
        initBarcodeScannerView()

        layoutParams = ViewGroup.LayoutParams(
            ViewGroup.LayoutParams.MATCH_PARENT,
            ViewGroup.LayoutParams.MATCH_PARENT,
        )

        setBackgroundColor(Color.BLACK)

        addView(barcodeScanner)
    }

    override fun onAttachedToWindow() {
        super.onAttachedToWindow()
        this.barcodeScanner.viewController.onResume()
    }

    override fun onDetachedFromWindow() {
        this.barcodeScanner.viewController.onPause()
        super.onDetachedFromWindow()
    }

    fun removeAttachedListeners() {
        (context as ReactContext).removeLifecycleEventListener(lifecycleEventListener)
    }

    private fun initBarcodeScannerView() {
        barcodeScanner = BarcodeScannerView(context).apply {
            initCamera(CameraUiSettings(true))

            initDetectionBehavior(barcodeDetector, {
                (it as? FrameHandlerResult.Success)?.value?.let { result ->
                    sendEvent(BarcodeScannerResultEvent(result))

                    addBarcodeItemOverlayViewInitialBinder(result)
                }

                false
            }, object : IBarcodeScannerViewCallback {
                override fun onCameraOpen() {
                    viewController.useFlash(flashState)
                }

                override fun onPictureTaken(image: ByteArray, captureInfo: CaptureInfo) {
                }

                override fun onSelectionOverlayBarcodeClicked(barcodeItem: BarcodeItem) {
                    sendEvent(BarcodeSelectionResultEvent(barcodeItem))
                }
            })

            viewController.barcodeDetectionInterval = BARCODE_DETECTION_INTERVAL

            configureFinderViewControllerWithDefaults(finderViewController)

            cameraConfiguration.setPhysicalZoomRange(CameraConfiguration.DEFAULT_ZOOM_RANGE)

            configureSelectionOverlayControllerWithDefaults(selectionOverlayController)

            (context as ReactContext).addLifecycleEventListener(lifecycleEventListener)
        }
    }

    private fun configureFinderViewControllerWithDefaults(finderViewController: IBarcodeScannerFinderViewController) {
        finderViewController.setStrokeColor(FinderViewConfiguration.DEFAULT_STROKE_COLOR)
        finderViewController.setOverlayColor(FinderViewConfiguration.DEFAULT_OVERLAY_COLOR)
        finderViewController.setFinderEnabled(FinderViewConfiguration.DEFAULT_FINDER_ENABLED)
        finderViewController.setStrokeWidth(
            FinderViewConfiguration.DEFAULT_STROKE_WIDTH.toPx(
                resources
            )
        )
        finderViewController.setFinderMinPadding(
            FinderViewConfiguration.DEFAULT_FINDER_MIN_PADDING.toPx(
                resources
            )
        )
        finderViewController.setFinderInset(
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.left.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.top.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.right.toPx(resources),
            FinderViewConfiguration.DEFAULT_FINDER_INSETS.bottom.toPx(resources)
        )
        finderViewController.setRequiredAspectRatios(FinderViewConfiguration.DEFAULT_ASPECT_RATIO)
    }

    private fun configureSelectionOverlayControllerWithDefaults(selectionOverlayController: IBarcodeScannerSelectionOverlayController) {
        selectionOverlayController.setBarcodeAppearanceDelegate(object :
            BarcodePolygonsView.BarcodeAppearanceDelegate {
            override fun getPolygonStyle(
                defaultStyle: BarcodePolygonsView.BarcodePolygonStyle, barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodePolygonStyle {
                return defaultStyle.copy(
                    fillColor = PolygonStyleConfig.DEFAULT_FILL_COLOR,
                    fillHighlightedColor = PolygonStyleConfig.DEFAULT_FILL_COLOR,
                    strokeColor = PolygonStyleConfig.DEFAULT_STROKE_COLOR,
                    strokeHighlightedColor = PolygonStyleConfig.DEFAULT_STROKE_COLOR
                )
            }

            override fun getTextViewStyle(
                defaultStyle: BarcodePolygonsView.BarcodeTextViewStyle, barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodeTextViewStyle {
                return defaultStyle.copy(
                    textColor = TextStyleConfig.DEFAULT_TEXT_COLOR,
                    textHighlightedColor = TextStyleConfig.DEFAULT_TEXT_COLOR,
                    textContainerColor = TextStyleConfig.DEFAULT_TEXT_CONTAINER_COLOR,
                    textContainerHighlightedColor = TextStyleConfig.DEFAULT_TEXT_CONTAINER_COLOR,
                    textFormat = TextStyleConfig.DEFAULT_TEXT_FORMAT
                )
            }
        })
    }

    override fun requestLayout() {
        super.requestLayout()
        post {
            layoutView()
        }
    }

    private fun View.layoutView() {
        measure(
            MeasureSpec.makeMeasureSpec(measuredWidth, MeasureSpec.EXACTLY),
            MeasureSpec.makeMeasureSpec(measuredHeight, MeasureSpec.EXACTLY)
        )
        layout(left, top, right, bottom)
    }

    private fun sendEvent(event: BaseEvent) {
        val surfaceId = UIManagerHelper.getSurfaceId(this)

        UIManagerHelper.getEventDispatcherForReactTag((context as ReactContext), id)
            ?.dispatchEvent(ComponentEvent(event, surfaceId, id))
    }

    private fun requestCameraPermissionIfNotGranted() {
        val activity: Activity = (context as ReactContext).currentActivity ?: return

        if (!cameraPermissionRequested &&
            ActivityCompat.checkSelfPermission(
                activity,
                Manifest.permission.CAMERA
            ) != PackageManager.PERMISSION_GRANTED
        ) {
            // shouldShowRequestPermissionRationale can be changed from another place in the app,
            // that's why we are using custom flag
            cameraPermissionRequested = true

            ActivityCompat.requestPermissions(
                activity,
                arrayOf(Manifest.permission.CAMERA),
                CAMERA_PERMISSION_REQUEST_CODE
            )
        }
    }

    fun setOverlayAppearance() {
        barcodeScanner.selectionOverlayController.setBarcodeAppearanceDelegate(object :
            BarcodePolygonsView.BarcodeAppearanceDelegate {
            override fun getPolygonStyle(
                defaultStyle: BarcodePolygonsView.BarcodePolygonStyle,
                barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodePolygonStyle {
                return barcodeItemOverlayViewBinders?.get(barcodeItem.uuid())
                    ?.let { overlayViewConfig ->
                        defaultStyle.copy(
                            fillColor = overlayViewConfig.polygonColorParsed
                                ?: polygonStyle.fillColor!!,
                            fillHighlightedColor = overlayViewConfig.polygonColorParsed
                                ?: polygonStyle.fillColor!!,
                            strokeColor = overlayViewConfig.strokeColorParsed
                                ?: polygonStyle.strokeColor!!,
                            strokeHighlightedColor = overlayViewConfig.strokeColorParsed
                                ?: polygonStyle.strokeColor!!,
                        )
                    } ?: run {
                    defaultStyle.copy(
                        fillColor = polygonStyle.fillColor!!,
                        fillHighlightedColor = polygonStyle.fillColor!!,
                        strokeColor = polygonStyle.strokeColor!!,
                        strokeHighlightedColor = polygonStyle.strokeColor!!,
                    )
                }
            }

            override fun getTextViewStyle(
                defaultStyle: BarcodePolygonsView.BarcodeTextViewStyle,
                barcodeItem: BarcodeItem
            ): BarcodePolygonsView.BarcodeTextViewStyle {
                return defaultStyle.copy(
                    textColor = textStyle.textColor!!,
                    textHighlightedColor = textStyle.textColor!!,
                    textContainerColor = textStyle.textContainerColor!!,
                    textContainerHighlightedColor = textStyle.textContainerColor!!,
                    textFormat = textStyle.textFormat!!
                )
            }
        })
    }

    private fun addBarcodeItemOverlayViewInitialBinder(barcodeResult: BarcodeScanningResult) {
        barcodeItemOverlayViewBinders?.let { bindersList ->
            barcodeResult.barcodeItems.forEach { barcodeItem ->
                val barcodeItemUuid = barcodeItem.uuid()

                if (!bindersList.contains(barcodeItemUuid)) {
                    bindersList[barcodeItemUuid] =
                        BarcodeItemOverlayViewConfig(text = BarcodeItemOverlayViewConfig.LOADING_TEXT)
                }
            }
        }
    }

    fun updateBarcodeItemOverlayViewBinder(
        barcodeItemUuid: String, barcodeItemOverlayViewConfig: BarcodeItemOverlayViewConfig
    ) {
        barcodeItemOverlayViewBinders?.let { bindersList ->
            if (bindersList.contains(barcodeItemUuid)) {
                bindersList[barcodeItemUuid] = barcodeItemOverlayViewConfig
            }
        }
    }

    fun setBarcodeItemOverlayViewBinderCallback() {
        if (barcodeItemOverlayViewBinders == null) {
            barcodeItemOverlayViewBinders = mutableMapOf()

            barcodeScanner.selectionOverlayController.setBarcodeItemViewBinder(
                barcodeItemOverlayViewBinder
            )
        }
    }
}
